# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: process.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import event_pb2 as event__pb2
from . import entity_pb2 as entity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='process.proto',
  package='schema',
  syntax='proto3',
  serialized_options=b'\n\023com.phisuite.schemaB\014ProcessProtoP\001',
  serialized_pb=b'\n\rprocess.proto\x12\x06schema\x1a\x0c\x63ommon.proto\x1a\x0b\x65vent.proto\x1a\x0c\x65ntity.proto\"\x80\x02\n\x07Process\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x1e\n\x06status\x18\x03 \x01(\x0e\x32\x0e.schema.Status\x12&\n\x05input\x18\x04 \x01(\x0b\x32\x17.schema.Process.Payload\x12\'\n\x06output\x18\x05 \x01(\x0b\x32\x17.schema.Process.Payload\x12\x1c\n\x05\x65rror\x18\x06 \x01(\x0b\x32\r.schema.Event\x1aG\n\x07Payload\x12\x1c\n\x05\x65vent\x18\x01 \x01(\x0b\x32\r.schema.Event\x12\x1e\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x0e.schema.Entity2\xe9\x01\n\nProcessAPI\x12*\n\x04List\x12\x0f.schema.Options\x1a\x0f.schema.Process0\x01\x12\'\n\x03Get\x12\x0f.schema.Options\x1a\x0f.schema.Process\x12*\n\x06\x43reate\x12\x0f.schema.Process\x1a\x0f.schema.Process\x12*\n\x06Update\x12\x0f.schema.Process\x1a\x0f.schema.Process\x12.\n\nDeactivate\x12\x0f.schema.Process\x1a\x0f.schema.ProcessB%\n\x13\x63om.phisuite.schemaB\x0cProcessProtoP\x01\x62\x06proto3'
  ,
  dependencies=[common__pb2.DESCRIPTOR,event__pb2.DESCRIPTOR,entity__pb2.DESCRIPTOR,])




_PROCESS_PAYLOAD = _descriptor.Descriptor(
  name='Payload',
  full_name='schema.Process.Payload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='schema.Process.Payload.event', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='schema.Process.Payload.entity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=323,
)

_PROCESS = _descriptor.Descriptor(
  name='Process',
  full_name='schema.Process',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='schema.Process.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='schema.Process.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='schema.Process.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='schema.Process.input', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output', full_name='schema.Process.output', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='schema.Process.error', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROCESS_PAYLOAD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=323,
)

_PROCESS_PAYLOAD.fields_by_name['event'].message_type = event__pb2._EVENT
_PROCESS_PAYLOAD.fields_by_name['entity'].message_type = entity__pb2._ENTITY
_PROCESS_PAYLOAD.containing_type = _PROCESS
_PROCESS.fields_by_name['status'].enum_type = common__pb2._STATUS
_PROCESS.fields_by_name['input'].message_type = _PROCESS_PAYLOAD
_PROCESS.fields_by_name['output'].message_type = _PROCESS_PAYLOAD
_PROCESS.fields_by_name['error'].message_type = event__pb2._EVENT
DESCRIPTOR.message_types_by_name['Process'] = _PROCESS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Process = _reflection.GeneratedProtocolMessageType('Process', (_message.Message,), {

  'Payload' : _reflection.GeneratedProtocolMessageType('Payload', (_message.Message,), {
    'DESCRIPTOR' : _PROCESS_PAYLOAD,
    '__module__' : 'process_pb2'
    # @@protoc_insertion_point(class_scope:schema.Process.Payload)
    })
  ,
  'DESCRIPTOR' : _PROCESS,
  '__module__' : 'process_pb2'
  # @@protoc_insertion_point(class_scope:schema.Process)
  })
_sym_db.RegisterMessage(Process)
_sym_db.RegisterMessage(Process.Payload)


DESCRIPTOR._options = None

_PROCESSAPI = _descriptor.ServiceDescriptor(
  name='ProcessAPI',
  full_name='schema.ProcessAPI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=326,
  serialized_end=559,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='schema.ProcessAPI.List',
    index=0,
    containing_service=None,
    input_type=common__pb2._OPTIONS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='schema.ProcessAPI.Get',
    index=1,
    containing_service=None,
    input_type=common__pb2._OPTIONS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='schema.ProcessAPI.Create',
    index=2,
    containing_service=None,
    input_type=_PROCESS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='schema.ProcessAPI.Update',
    index=3,
    containing_service=None,
    input_type=_PROCESS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Deactivate',
    full_name='schema.ProcessAPI.Deactivate',
    index=4,
    containing_service=None,
    input_type=_PROCESS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSAPI)

DESCRIPTOR.services_by_name['ProcessAPI'] = _PROCESSAPI

# @@protoc_insertion_point(module_scope)
