# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import common_pb2 as common__pb2
from . import entity_pb2 as entity__pb2


class EntityAPIStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.List = channel.unary_stream(
        '/schema.EntityAPI/List',
        request_serializer=common__pb2.Options.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Get = channel.unary_unary(
        '/schema.EntityAPI/Get',
        request_serializer=common__pb2.Options.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Create = channel.unary_unary(
        '/schema.EntityAPI/Create',
        request_serializer=entity__pb2.Entity.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Update = channel.unary_unary(
        '/schema.EntityAPI/Update',
        request_serializer=entity__pb2.Entity.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Activate = channel.unary_unary(
        '/schema.EntityAPI/Activate',
        request_serializer=entity__pb2.Entity.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Deactivate = channel.unary_unary(
        '/schema.EntityAPI/Deactivate',
        request_serializer=entity__pb2.Entity.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )


class EntityAPIServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Activate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Deactivate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_EntityAPIServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'List': grpc.unary_stream_rpc_method_handler(
          servicer.List,
          request_deserializer=common__pb2.Options.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=common__pb2.Options.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=entity__pb2.Entity.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=entity__pb2.Entity.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Activate': grpc.unary_unary_rpc_method_handler(
          servicer.Activate,
          request_deserializer=entity__pb2.Entity.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Deactivate': grpc.unary_unary_rpc_method_handler(
          servicer.Deactivate,
          request_deserializer=entity__pb2.Entity.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'schema.EntityAPI', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
